# xm2xl
Flatten Xmind file into xlsx sheet

## Installation

pip install xm2xl

## Usage

     Usage : xm2xl <Xmind File> <flags>
     
     Flags
        -s, --sheet=SHEET : Sheet to read data from
            Default: ''
        -o, --outputfile=OUTPUTFILE : Name of the output file
            Default: ''